@@ -1,9 +1,10 @@
 from .buoy import Buoy
 from .buoy_data import BuoyData
-from .source import Source
+from .source import Source, SourceType
 
 __all__ = [
     'Buoy',
     'BuoyData',
-    'Source'
+    'Source',
+    'SourceType'
 ]
